@@ -1,34 +1,41 @@
 <?php
-/*
- * @version $Id: dbconnection.class.php 20130 2013-02-04 16:55:15Z moyo $
- -------------------------------------------------------------------------
- GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
-
- http://indepnet.net/   http://glpi-project.org
- -------------------------------------------------------------------------
-
- LICENSE
-
- This file is part of GLPI.
-
- GLPI is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- GLPI is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with GLPI. If not, see <http://www.gnu.org/licenses/>.
- --------------------------------------------------------------------------
+/**
+ * ---------------------------------------------------------------------
+ * GLPI - Gestionnaire Libre de Parc Informatique
+ * Copyright (C) 2015-2017 Teclib' and contributors.
+ *
+ * http://glpi-project.org
+ *
+ * based on GLPI - Gestionnaire Libre de Parc Informatique
+ * Copyright (C) 2003-2014 by the INDEPNET Development Team.
+ *
+ * ---------------------------------------------------------------------
+ *
+ * LICENSE
+ *
+ * This file is part of GLPI.
+ *
+ * GLPI is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * GLPI is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GLPI. If not, see <http://www.gnu.org/licenses/>.
+ * ---------------------------------------------------------------------
  */
 
+/** @file
+* @brief
+*/
+
 if (!defined('GLPI_ROOT')) {
-   die("Sorry. You can't access directly to this file");
+   die("Sorry. You can't access this file directly");
 }
 
 
@@ -37,29 +44,53 @@ if (!defined('GLPI_ROOT')) {
 **/
 class DBConnection extends CommonDBTM {
 
-   var $notable = true;
+   static protected $notable = true;
 
 
-   static function getTypeName() {
-      global $LANG;
+   static function getTypeName($nb = 0) {
+      return _n('SQL replica', 'SQL replicas', $nb);
+   }
 
-      return $LANG['setup'][800];
+
+   /**
+    * Create GLPI main configuration file
+    *
+    * @since 9.1
+    *
+    * @param $dbhost
+    * @param $user
+    * @param $password
+    * @param $DBname
+    *
+    * @return boolean
+    *
+   **/
+   static function createMainConfig($host, $user, $password, $DBname) {
+
+      $DB_str = "<?php\nclass DB extends DBmysql {\n" .
+                "   public \$dbhost     = '$host';\n" .
+                "   public \$dbuser     = '$user';\n" .
+                "   public \$dbpassword = '". rawurlencode($password) . "';\n" .
+                "   public \$dbdefault  = '$DBname';\n" .
+                "}\n";
+
+      return Toolbox::writeConfig('config_db.php', $DB_str);
    }
 
 
    /**
     * Create slave DB configuration file
     *
-    * @param host the slave DB host(s)
-    * @param user the slave DB user
-    * @param password the slave DB password
-    * @param DBname the name of the slave DB
+    * @param host       the slave DB host(s)
+    * @param user       the slave DB user
+    * @param password   the slave DB password
+    * @param DBname     the name of the slave DB
     *
     * @return boolean for success
    **/
    static function createSlaveConnectionFile($host, $user, $password, $DBname) {
 
-      $DB_str = "<?php \n class DBSlave extends DBmysql { \n var \$slave = true; \n var \$dbhost = ";
+      $DB_str = "<?php \n class DBSlave extends DBmysql { \n public \$slave = true; \n public \$dbhost = ";
       $host   = trim($host);
       if (strpos($host, ' ')) {
          $hosts = explode(' ', $host);
@@ -79,15 +110,10 @@ class DBConnection extends CommonDBTM {
       } else {
          $DB_str .= "'$host';\n";
       }
-      $DB_str .= " var \$dbuser = '" . $user . "'; \n var \$dbpassword= '" .
-                  rawurlencode($password) . "'; \n var \$dbdefault = '" . $DBname . "'; \n } \n ?>";
-      $fp      = fopen(GLPI_CONFIG_DIR . "/config_db_slave.php", 'wt');
-      if ($fp) {
-         $fw = fwrite($fp, $DB_str);
-         fclose($fp);
-         return true;
-      }
-      return false;
+      $DB_str .= " public \$dbuser = '" . $user . "'; \n public \$dbpassword= '" .
+                  rawurlencode($password) . "'; \n public \$dbdefault = '" . $DBname . "'; \n }\n";
+
+      return Toolbox::writeConfig('config_db_slave.php', $DB_str);
    }
 
 
@@ -97,7 +123,6 @@ class DBConnection extends CommonDBTM {
     * @return true if active / false if not active
    **/
    static function isDBSlaveActive() {
-
       return file_exists(GLPI_CONFIG_DIR . "/config_db_slave.php");
    }
 
@@ -105,11 +130,11 @@ class DBConnection extends CommonDBTM {
    /**
     * Read slave DB configuration file
     *
-    * @param $choice integer, host number
+    * @param $choice integer, host number (default NULL)
     *
     * @return DBmysql object
    **/
-   static function getDBSlaveConf($choice=NULL) {
+   static function getDBSlaveConf($choice = null) {
 
       if (self::isDBSlaveActive()) {
          include_once (GLPI_CONFIG_DIR . "/config_db_slave.php");
@@ -122,16 +147,19 @@ class DBConnection extends CommonDBTM {
     * Create a default slave DB configuration file
    **/
    static function createDBSlaveConfig() {
-
       self::createSlaveConnectionFile("localhost", "glpi", "glpi", "glpi");
    }
 
 
    /**
     * Save changes to the slave DB configuration file
+    *
+    * @param $host
+    * @param $user
+    * @param $password
+    * @param $DBname
    **/
    static function saveDBSlaveConf($host, $user, $password, $DBname) {
-
       self::createSlaveConnectionFile($host, $user, $password, $DBname);
    }
 
@@ -140,7 +168,6 @@ class DBConnection extends CommonDBTM {
     * Delete slave DB configuration file
     */
    static function deleteDBSlaveConfig() {
-
       unlink(GLPI_CONFIG_DIR . "/config_db_slave.php");
    }
 
@@ -190,6 +217,7 @@ class DBConnection extends CommonDBTM {
          if ($DBread->connected) {
             $sql = "SELECT MAX(`id`) AS maxid
                     FROM `glpi_logs`";
+
             switch ($CFG_GLPI['use_slave_for_search']) {
                case 3 : // If synced or read-only account
                   if (Session::isReadOnlyAccount()) {
@@ -232,12 +260,12 @@ class DBConnection extends CommonDBTM {
    /**
     *  Establish a connection to a mysql server (main or replicate)
     *
-    * @param $use_slave try to connect to slave server first not to main server
-    * @param $required connection to the specified server is required
-    *                  (if connection failed, do not try to connect to the other server)
-    * @param $display display error message
+    * @param $use_slave    try to connect to slave server first not to main server
+    * @param $required     connection to the specified server is required
+    *                      (if connection failed, do not try to connect to the other server)
+    * @param $display      display error message (true by default)
    **/
-   static function establishDBConnection($use_slave, $required, $display=true) {
+   static function establishDBConnection($use_slave, $required, $display = true) {
       global $DB;
 
       $DB  = null;
@@ -259,8 +287,7 @@ class DBConnection extends CommonDBTM {
                $res = self::switchToMaster();
             }
 
-         // Slave DB configured
-         } else {
+         } else { // Slave DB configured
             // Try to connect to slave if wanted
             if ($use_slave) {
                $res = self::switchToSlave();
@@ -275,7 +302,7 @@ class DBConnection extends CommonDBTM {
                   $res = self::switchToSlave();
                }
                if ($res) {
-                  $DB->first_connection=false;
+                  $DB->first_connection = false;
                }
             }
          }
@@ -292,11 +319,11 @@ class DBConnection extends CommonDBTM {
    /**
     * Get delay between slave and master
     *
-    * @param $choice integer, host number
+    * @param $choice integer, host number (default NULL)
     *
     * @return integer
    **/
-   static function getReplicateDelay($choice=NULL) {
+   static function getReplicateDelay($choice = null) {
 
       include_once (GLPI_CONFIG_DIR . "/config_db_slave.php");
       return (int) (self::getHistoryMaxDate(new DB())
@@ -327,30 +354,30 @@ class DBConnection extends CommonDBTM {
    **/
    static function displayMySQLError() {
 
-      Html::nullHeader("Mysql Error", '');
-
       if (!isCommandLine()) {
+         Html::nullHeader("Mysql Error", '');
          echo "<div class='center'><p class ='b'>
-                A link to the Mysql server could not be established. Please check your configuration.
+                A link to the SQL server could not be established. Please check your configuration.
                 </p><p class='b'>
-                Le serveur Mysql est inaccessible. V&eacute;rifiez votre configuration</p>
+                Le serveur Mysql est inaccessible. Vérifiez votre configuration</p>
                </div>";
-
+         Html::nullFooter();
       } else {
-         echo "A link to the Mysql server could not be established. Please check your configuration.\n";
-         echo "Le serveur Mysql est inaccessible. V&eacute;rifiez votre configuration\n";
+         echo "A link to the SQL server could not be established. Please check your configuration.\n";
+         echo "Le serveur Mysql est inaccessible. Vérifiez votre configuration\n";
       }
 
-      Html::nullFooter();
       die();
    }
 
 
+   /**
+    * @param $name
+   **/
    static function cronInfo($name) {
-      global $LANG;
 
-      return array('description' => $LANG['crontask'][10],
-                   'parameter'   => $LANG['setup'][806]);
+      return ['description' => __('Check the SQL replica'),
+                   'parameter'   => __('Max delay between master and slave (minutes)')];
    }
 
 
@@ -360,7 +387,7 @@ class DBConnection extends CommonDBTM {
     * @param $task to log and get param
    **/
    static function cronCheckDBreplicate($task) {
-      global $DB, $LANG;
+      global $DB;
 
       //Lauch cron only is :
       // 1 the master database is avalaible
@@ -371,7 +398,7 @@ class DBConnection extends CommonDBTM {
          if (is_array($DBslave->dbhost)) {
             $hosts = $DBslave->dbhost;
          } else {
-            $hosts = array($DBslave->dbhost);
+            $hosts = [$DBslave->dbhost];
          }
 
          foreach ($hosts as $num => $name) {
@@ -380,17 +407,18 @@ class DBConnection extends CommonDBTM {
             // Quite strange, but allow simple stat
             $task->addVolume($diff);
             if ($diff > 1000000000) { // very large means slave is disconnect
-               $task->log($LANG['install'][30]." : '$name', ".$LANG['install'][35]);
+               $task->log(sprintf(__s("SQL server: %s can't connect to the database"), $name));
             } else {
-               $task->log($LANG['install'][30]." : '$name', ".
-                          $LANG['setup'][803]." : ".Html::timestampToString($diff, true));
+                                  //TRANS: %1$s is the server name, %2$s is the time
+               $task->log(sprintf(__('SQL server: %1$s, difference between master and slave: %2$s'),
+                                  $name, Html::timestampToString($diff, true)));
             }
 
             if ($diff > ($task->fields['param']*60)) {
                //Raise event if replicate is not synchronized
-               $options = array('diff'        => $diff,
+               $options = ['diff'        => $diff,
                                 'name'        => $name,
-                                'entities_id' => 0); // entity to avoid warning in getReplyTo
+                                'entities_id' => 0]; // entity to avoid warning in getReplyTo
                NotificationEvent::raiseEvent('desynchronization', new self(), $options);
             }
          }
@@ -405,42 +433,47 @@ class DBConnection extends CommonDBTM {
     * 1 line per slave is multiple
    **/
    static function showAllReplicateDelay() {
-      global $LANG;
 
-      $DBSlave = self::getDBSlaveConf();
+      $DBslave = self::getDBSlaveConf();
 
-      if (is_array($DBSlave->dbhost)) {
-         $hosts = $DBSlave->dbhost;
+      if (is_array($DBslave->dbhost)) {
+         $hosts = $DBslave->dbhost;
       } else {
-         $hosts = array($DBSlave->dbhost);
+         $hosts = [$DBslave->dbhost];
       }
 
       foreach ($hosts as $num => $name) {
          $diff = self::getReplicateDelay($num);
-         echo $LANG['install'][30] . "&nbsp;: '$name', ";
+         //TRANS: %s is namez of server Mysql
+         printf(__('%1$s: %2$s'), __('SQL server'), $name);
+         echo " - ";
          if ($diff > 1000000000) {
-            echo $LANG['install'][35] . "<br>";
+            echo __("can't connect to the database") . "<br>";
          } else if ($diff) {
-            echo $LANG['setup'][803] . "&nbsp;: " . Html::timestampToString($diff, 1) . "<br>";
+            printf(__('%1$s: %2$s')."<br>", __('Difference between master and slave'),
+                   Html::timestampToString($diff, 1));
          } else {
-            echo $LANG['setup'][803] . "&nbsp;: " . $LANG['common'][49] . "<br>";
+            printf(__('%1$s: %2$s')."<br>", __('Difference between master and slave'), __('None'));
          }
       }
    }
 
 
+   /**
+    * @param $width
+   **/
    function showSystemInformations($width) {
-      global $LANG;
 
-      echo "\n</pre></td>";
-      echo "</tr><tr class='tab_bg_2'><th>" . $LANG['setup'][800] . "</th></tr>";
+      // No need to translate, this part always display in english (for copy/paste to forum)
+
+      echo "<tr class='tab_bg_2'><th>".self::getTypeName(Session::getPluralNumber())."</th></tr>";
 
       echo "<tr class='tab_bg_1'><td><pre>\n&nbsp;\n";
       if (self::isDBSlaveActive()) {
-         echo $LANG['common'][60]."&nbsp;: ".$LANG['choice'][1]." \n";
+         echo "Active\n";
          self::showAllReplicateDelay();
       } else {
-         echo $LANG['common'][60]."&nbsp;: ".$LANG['choice'][0]."\n";
+         echo "Not active\n";
       }
       echo "\n</pre></td></tr>";
    }
@@ -449,11 +482,11 @@ class DBConnection extends CommonDBTM {
    /**
     * Enable or disable db replication check cron task
     *
-    * @param enable of disable cron task
+    * @param enable of disable cron task (true by default)
    **/
-   static function changeCronTaskStatus($enable=true) {
+   static function changeCronTaskStatus($enable = true) {
 
-      $cron = new CronTask();
+      $cron           = new CronTask();
       $cron->getFromDBbyName('DBConnection', 'CheckDBreplicate');
       $input['id']    = $cron->fields['id'];
       $input['state'] = ($enable?1:0);
@@ -461,4 +494,3 @@ class DBConnection extends CommonDBTM {
    }
 
 }
-?>
\ No newline at end of file
