@@ -673,12 +673,12 @@ final class DbUtils {
       global $DB, $GLPI_CACHE;
 
       $ckey = $table . '_sons_cache_' . $IDf;
-      $sons = [];
+      $sons = false;
 
       if (Toolbox::useCache()) {
          if ($GLPI_CACHE->hasItem($ckey)) {
             $sons = $GLPI_CACHE->getItem($ckey);
-            if ($sons) {
+            if ($sons !== null) {
                return $sons;
             }
          }
@@ -697,14 +697,14 @@ final class DbUtils {
          ]);
 
          if (count($iterator) > 0) {
-            $db_sons = trim($iterator->current()['sons_cache']);
+            $db_sons = trim($iterator->next()['sons_cache']);
             if (!empty($db_sons)) {
                $sons = $this->importArrayFromDB($db_sons, true);
             }
          }
       }
 
-      if (!count($sons)) {
+      if (!is_array($sons)) {
          // IDs to be present in the final array
          $sons[$IDf] = "$IDf";
          // current ID found to be added
@@ -787,7 +787,7 @@ final class DbUtils {
       if (Toolbox::useCache()) {
          if ($GLPI_CACHE->hasItem($ckey)) {
             $ancestors = $GLPI_CACHE->getItem($ckey);
-            if ($ancestors) {
+            if ($ancestors !== null) {
                return $ancestors;
             }
          }
@@ -854,7 +854,7 @@ final class DbUtils {
                ]);
 
                if (count($iterator) > 0) {
-                  $result = $iterator->current();
+                  $result = $iterator->next();
                   $IDf = $result[$parentIDfield];
                } else {
                   $IDf = 0;
@@ -1070,7 +1070,7 @@ final class DbUtils {
       $name = "";
 
       if (count($iterator) > 0) {
-         $row      = $iterator->current();
+         $row      = $iterator->next();
          $parentID = $row[$parentIDfield];
 
          if ($wholename == "") {
@@ -1275,7 +1275,7 @@ final class DbUtils {
          ]);
 
          if (count($iterator) > 0) {
-            $search = addslashes($iterator->current()[$nextprev_item]);
+            $search = addslashes($iterator->next()[$nextprev_item]);
          } else {
             $nextprev_item = "id";
          }
@@ -1364,7 +1364,7 @@ final class DbUtils {
          ]);
 
          if (count($iterator) > 0) {
-            $search = addslashes($iterator->current()[$nextprev_item]);
+            $search = addslashes($iterator->next()[$nextprev_item]);
          } else {
             $nextprev_item = "id";
          }
