@@ -1,49 +1,65 @@
 <?php
-/*
- * @version $Id: displaypreference.class.php 20130 2013-02-04 16:55:15Z moyo $
- -------------------------------------------------------------------------
- GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
-
- http://indepnet.net/   http://glpi-project.org
- -------------------------------------------------------------------------
-
- LICENSE
-
- This file is part of GLPI.
-
- GLPI is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- GLPI is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with GLPI. If not, see <http://www.gnu.org/licenses/>.
- --------------------------------------------------------------------------
+/**
+ * ---------------------------------------------------------------------
+ * GLPI - Gestionnaire Libre de Parc Informatique
+ * Copyright (C) 2015-2017 Teclib' and contributors.
+ *
+ * http://glpi-project.org
+ *
+ * based on GLPI - Gestionnaire Libre de Parc Informatique
+ * Copyright (C) 2003-2014 by the INDEPNET Development Team.
+ *
+ * ---------------------------------------------------------------------
+ *
+ * LICENSE
+ *
+ * This file is part of GLPI.
+ *
+ * GLPI is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * GLPI is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GLPI. If not, see <http://www.gnu.org/licenses/>.
+ * ---------------------------------------------------------------------
  */
 
-// ----------------------------------------------------------------------
-// Original Author of file:
-// Purpose of file:
-// ----------------------------------------------------------------------
+/** @file
+* @brief
+*/
 
 if (!defined('GLPI_ROOT')) {
-   die("Sorry. You can't access directly to this file");
+   die("Sorry. You can't access this file directly");
 }
 
-
 class DisplayPreference extends CommonDBTM {
 
+   // From CommonGLPI
+   public $taborientation          = 'horizontal';
+   public $get_item_to_display_tab = false;
+
    // From CommonDBTM
-   var $auto_message_on_action = false;
+   public $auto_message_on_action  = false;
 
-   protected $displaylist = false;
+   protected $displaylist          = false;
 
+
+   static $rightname = 'search_config';
+
+   const PERSONAL = 1024;
+   const GENERAL  = 2048;
+
+
+
+   /**
+    * @see CommonDBTM::prepareInputForAdd()
+   **/
    function prepareInputForAdd($input) {
       global $DB;
 
@@ -53,58 +69,89 @@ class DisplayPreference extends CommonDBTM {
                       AND `users_id` = '".$input["users_id"]."'";
       $result = $DB->query($query);
 
-      $input["rank"] = $DB->result($result,0,0)+1;
+      $input["rank"] = $DB->result($result, 0, 0)+1;
 
       return $input;
    }
 
 
    /**
-    * Get display preference for an user for an itemtype
+    * @since version 0.85
     *
-    * @param $itemtype itemtype
-    * @param $user_id user ID
+    * @see CommonDBTM::processMassiveActionsForOneItemtype()
+   **/
+   static function processMassiveActionsForOneItemtype(MassiveAction $ma, CommonDBTM $item,
+                                                       array $ids) {
+
+      switch ($ma->getAction()) {
+         case 'delete_for_user' :
+            $input = $ma->getInput();
+            if (isset($input['users_id'])) {
+               $user = new User();
+               $user->getFromDB($input['users_id']);
+               foreach ($ids as $id) {
+                  if ($input['users_id'] == Session::getLoginUserID()) {
+                     if ($item->deleteByCriteria(['users_id' => $input['users_id'],
+                                                       'itemtype' => $id])) {
+                        $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_OK);
+                     } else {
+                        $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_KO);
+                        $ma->addMessage($user->getErrorMessage(ERROR_ON_ACTION));
+                     }
+                  } else {
+                     $ma->itemDone($item->getType(), $id, MassiveAction::ACTION_NORIGHT);
+                     $ma->addMessage($user->getErrorMessage(ERROR_RIGHT));
+                  }
+               }
+            } else {
+               $ma->itemDone($item->getType(), $ids, MassiveAction::ACTION_KO);
+            }
+            return;
+      }
+      parent::processMassiveActionsForOneItemtype($ma, $item, $ids);
+   }
+
+
+   /**
+    * Get display preference for a user for an itemtype
+    *
+    * @param $itemtype  itemtype
+    * @param $user_id   user ID
    **/
    static function getForTypeUser($itemtype, $user_id) {
       global $DB;
 
-      // Add default items for user
       $query = "SELECT *
                 FROM `glpi_displaypreferences`
                 WHERE `itemtype` = '$itemtype'
-                      AND `users_id` = '$user_id'
-                ORDER BY `rank`";
+                      AND (`users_id` = '$user_id' OR `users_id` = '0')
+                ORDER BY `users_id`, `rank`";
       $result = $DB->query($query);
 
-      // GET default serach options
-      if ($DB->numrows($result)==0) {
-         $query = "SELECT *
-                   FROM `glpi_displaypreferences`
-                   WHERE `itemtype` = '$itemtype'
-                         AND `users_id` = '0'
-                   ORDER BY `rank`";
-         $result = $DB->query($query);
-      }
+      $default_prefs = [];
+      $user_prefs = [];
 
-      $prefs = array();
-      if ($DB->numrows($result)>0) {
-         while ($data=$DB->fetch_array($result)) {
-            array_push($prefs, $data["num"]);
+      while ($data = $DB->fetch_assoc($result)) {
+         if ($data["users_id"] != 0) {
+            $user_prefs[] = $data["num"];
+         } else {
+            $default_prefs[] = $data["num"];
          }
       }
-      return $prefs;
+
+      return count($user_prefs) ? $user_prefs : $default_prefs;
    }
 
 
    /**
     * Active personal config based on global one
     *
-    * @param $input parameter array (itemtype,users_id)
+    * @param $input  array parameter (itemtype,users_id)
    **/
-   function activatePerso($input) {
+   function activatePerso(array $input) {
       global $DB;
 
-      if (!Session::haveRight("search_config", "w")) {
+      if (!Session::haveRight(self::$rightname, self::PERSONAL)) {
          return false;
       }
 
@@ -115,7 +162,7 @@ class DisplayPreference extends CommonDBTM {
       $result = $DB->query($query);
 
       if ($DB->numrows($result)) {
-         while ($data=$DB->fetch_assoc($result)) {
+         while ($data = $DB->fetch_assoc($result)) {
             unset($data["id"]);
             $data["users_id"] = $input["users_id"];
             $this->fields     = $data;
@@ -125,11 +172,14 @@ class DisplayPreference extends CommonDBTM {
       } else {
          // No items in the global config
          $searchopt = Search::getOptions($input["itemtype"]);
-         if (count($searchopt)>1) {
+         if (count($searchopt) > 1) {
             $done = false;
 
             foreach ($searchopt as $key => $val) {
-               if (is_array($val) && $key!=1 && !$done) {
+               if (is_array($val)
+                   && ($key != 1)
+                   && !$done) {
+
                   $data["users_id"] = $input["users_id"];
                   $data["itemtype"] = $input["itemtype"];
                   $data["rank"]     = 1;
@@ -147,10 +197,10 @@ class DisplayPreference extends CommonDBTM {
    /**
     * Order to move an item
     *
-    * @param $input parameter array (id,itemtype,users_id)
-    * @param $action up or down
+    * @param $input  array parameter (id,itemtype,users_id)
+    * @param $action       up or down
    **/
-   function orderItem($input, $action) {
+   function orderItem(array $input, $action) {
       global $DB;
 
       // Get current item
@@ -201,21 +251,21 @@ class DisplayPreference extends CommonDBTM {
    /**
     * Print the search config form
     *
-    * @param $target form target
-    * @param $itemtype item type
+    * @param $target    form target
+    * @param $itemtype  item type
     *
     * @return nothing
    **/
-   function showFormPerso($target,$itemtype) {
-      global $CFG_GLPI, $LANG, $DB;
+   function showFormPerso($target, $itemtype) {
+      global $CFG_GLPI, $DB;
 
       $searchopt = Search::getCleanedOptions($itemtype);
       if (!is_array($searchopt)) {
          return false;
       }
 
-      $item = NULL;
-      if ($itemtype!='States') {
+      $item = null;
+      if ($itemtype != 'AllAssets') {
          $item = getItemForItemtype($itemtype);
       }
 
@@ -232,14 +282,15 @@ class DisplayPreference extends CommonDBTM {
       $numrows = 0;
       $numrows = $DB->numrows($result);
 
-      if ($numrows==0) {
-         Session::checkRight("search_config", "w");
+      if ($numrows == 0) {
+         Session::checkRight(self::$rightname, self::PERSONAL);
          echo "<table class='tab_cadre_fixe'><tr><th colspan='4'>";
          echo "<form method='post' action='$target'>";
          echo "<input type='hidden' name='itemtype' value='$itemtype'>";
          echo "<input type='hidden' name='users_id' value='$IDuser'>";
-         echo $LANG['setup'][241]."<span class='small_space'>";
-         echo "<input type='submit' name='activate' value=\"".$LANG['buttons'][2]."\" class='submit'>";
+         echo __('No personal criteria. Create personal parameters?')."<span class='small_space'>";
+         echo "<input type='submit' name='activate' value=\"".__('Create')."\"
+                class='submit'>";
          echo "</span>";
          Html::closeForm();
          echo "</th></tr></table>\n";
@@ -248,34 +299,39 @@ class DisplayPreference extends CommonDBTM {
          $already_added = self::getForTypeUser($itemtype, $IDuser);
 
          echo "<table class='tab_cadre_fixe'><tr><th colspan='4'>";
-         echo $LANG['setup'][252]."&nbsp;: </th></tr>";
+         echo "<form method='post' action='$target'>";
+         echo "<input type='hidden' name='itemtype' value='$itemtype'>";
+         echo "<input type='hidden' name='users_id' value='$IDuser'>";
+         echo __('Select default items to show')."<span class='small_space'>";
+         echo "<input type='submit' name='disable' value=\"".__('Delete')."\"
+                class='submit'>";
+         echo "</span>";
+         Html::closeForm();
+
+         echo "</th></tr>";
          echo "<tr class='tab_bg_1'><td colspan='4' class='center'>";
          echo "<form method='post' action=\"$target\">";
          echo "<input type='hidden' name='itemtype' value='$itemtype'>";
          echo "<input type='hidden' name='users_id' value='$IDuser'>";
-         echo "<select name='num'>";
-         $first_group = true;
-
+         $group  = '';
+         $values = [];
          foreach ($searchopt as $key => $val) {
             if (!is_array($val)) {
-               if (!$first_group) {
-                  echo "</optgroup>\n";
-               } else {
-                  $first_group = false;
-               }
-               echo "<optgroup label=\"$val\">";
-
-            } else if ($key!=1 && !in_array($key,$already_added)) {
-               echo "<option value='$key'>".$val["name"]."</option>\n";
+               $group = $val;
+            } else if (count($val) === 1) {
+               $group = $val['name'];
+            } else if ($key != 1
+                       && !in_array($key, $already_added)
+                       && (!isset($val['nodisplay']) || !$val['nodisplay'])) {
+               $values[$group][$key] = $val["name"];
             }
          }
-
-         if (!$first_group) {
-            echo "</optgroup>\n";
+         if ($values) {
+            Dropdown::showFromArray('num', $values);
+            echo "<span class='small_space'>";
+            echo "<input type='submit' name='add' value=\""._sx('button', 'Add')."\" class='submit'>";
+            echo "</span>";
          }
-         echo "</select><span class='small_space'>";
-         echo "<input type='submit' name='add' value=\"".$LANG['buttons'][8]."\" class='submit'>";
-         echo "</span>";
          Html::closeForm();
          echo "</td></tr>\n";
 
@@ -285,12 +341,11 @@ class DisplayPreference extends CommonDBTM {
          echo "<td colspan='3'>&nbsp;</td>";
          echo "</tr>";
 
-
          // print entity
          if (Session::isMultiEntitiesMode()
              && (isset($CFG_GLPI["union_search_type"][$itemtype])
                  || ($item && $item->maybeRecursive())
-                 || count($_SESSION["glpiactiveentities"])>1)
+                 || (count($_SESSION["glpiactiveentities"]) > 1))
              && isset($searchopt[80])) {
 
             echo "<tr class='tab_bg_2'>";
@@ -301,21 +356,21 @@ class DisplayPreference extends CommonDBTM {
 
          $i = 0;
          if ($numrows) {
-            while ($data=$DB->fetch_array($result)) {
-               if ($data["num"]!=1 && isset($searchopt[$data["num"]])) {
+            while ($data = $DB->fetch_assoc($result)) {
+               if (($data["num"] !=1) && isset($searchopt[$data["num"]])) {
                   echo "<tr class='tab_bg_2'>";
                   echo "<td class='center' width='50%' >";
                   echo $searchopt[$data["num"]]["name"]."</td>";
 
-                  if ($i!=0) {
+                  if ($i != 0) {
                      echo "<td class='center middle'>";
                      echo "<form method='post' action='$target'>";
                      echo "<input type='hidden' name='id' value='".$data["id"]."'>";
                      echo "<input type='hidden' name='users_id' value='$IDuser'>";
                      echo "<input type='hidden' name='itemtype' value='$itemtype'>";
-                     echo "<input type='image' name='up' value=\"".$LANG['buttons'][24]."\" src='".
-                            $CFG_GLPI["root_doc"]."/pics/puce-up2.png' alt=\"".
-                            $LANG['buttons'][24]."\" title=\"".$LANG['buttons'][24]."\">";
+                     echo "<button type='submit' name='up'".
+                         " title=\"".__s('Bring up')."\"".
+                         " class='unstyled pointer'><i class='fa fa-arrow-up'></i></button>";
                      Html::closeForm();
                      echo "</td>\n";
 
@@ -323,15 +378,15 @@ class DisplayPreference extends CommonDBTM {
                      echo "<td>&nbsp;</td>";
                   }
 
-                  if ($i!=$numrows-1) {
+                  if ($i != ($numrows-1)) {
                      echo "<td class='center middle'>";
                      echo "<form method='post' action='$target'>";
                      echo "<input type='hidden' name='id' value='".$data["id"]."'>";
                      echo "<input type='hidden' name='users_id' value='$IDuser'>";
                      echo "<input type='hidden' name='itemtype' value='$itemtype'>";
-                     echo "<input type='image' name='down' value=\"".$LANG['buttons'][25]."\" src='".
-                            $CFG_GLPI["root_doc"]."/pics/puce-down2.png' alt=\"".
-                            $LANG['buttons'][25]."\" title=\"".$LANG['buttons'][25]."\">";
+                     echo "<button type='submit' name='down'".
+                         " title=\"".__s('Bring down')."\"".
+                         " class='unstyled pointer'><i class='fa fa-arrow-down'></i></button>";
                      Html::closeForm();
                      echo "</td>\n";
 
@@ -344,9 +399,9 @@ class DisplayPreference extends CommonDBTM {
                   echo "<input type='hidden' name='id' value='".$data["id"]."'>";
                   echo "<input type='hidden' name='users_id' value='$IDuser'>";
                   echo "<input type='hidden' name='itemtype' value='$itemtype'>";
-                  echo "<input type='image' name='delete' value=\"".$LANG['buttons'][6]."\" src='".
-                         $CFG_GLPI["root_doc"]."/pics/puce-delete2.png' alt=\"".
-                         $LANG['buttons'][6]."\" title=\"".$LANG['buttons'][6]."\">";
+                  echo "<button type='submit' name='purge'".
+                         " title=\""._sx('button', 'Delete permanently')."\"".
+                         " class='unstyled pointer'><i class='fa fa-times-circle'></i></button>";
                   Html::closeForm();
                   echo "</td>\n";
                   echo "</tr>";
@@ -363,26 +418,26 @@ class DisplayPreference extends CommonDBTM {
    /**
     * Print the search config form
     *
-    * @param $target form target
-    * @param $itemtype item type
+    * @param $target    form target
+    * @param $itemtype  item type
     *
     * @return nothing
    **/
-   function showFormGlobal($target,$itemtype) {
-      global $CFG_GLPI, $LANG, $DB;
+   function showFormGlobal($target, $itemtype) {
+      global $CFG_GLPI, $DB;
 
-      $searchopt = Search::getOptions($itemtype);
+      $searchopt = Search::getCleanedOptions($itemtype);
       if (!is_array($searchopt)) {
          return false;
       }
       $IDuser = 0;
 
-      $item = NULL;
-      if ($itemtype!='States') {
+      $item = null;
+      if ($itemtype != 'AllAssets') {
          $item = getItemForItemtype($itemtype);
       }
 
-      $global_write = Session::haveRight("search_config_global", "w");
+      $global_write = Session::haveRight(self::$rightname, self::GENERAL);
 
       echo "<div class='center' id='tabsbody' >";
       // Defined items
@@ -395,8 +450,8 @@ class DisplayPreference extends CommonDBTM {
       $result  = $DB->query($query);
       $numrows = $DB->numrows($result);
 
-      echo "<table class='tab_cadre_fixe'><tr><th colspan='4'>";
-      echo $LANG['setup'][252]."&nbsp;: </th></tr>\n";
+      echo "<table class='tab_cadre_fixehov'><tr><th colspan='4'>";
+      echo __('Select default items to show')."</th></tr>\n";
 
       if ($global_write) {
          $already_added = self::getForTypeUser($itemtype, $IDuser);
@@ -404,31 +459,25 @@ class DisplayPreference extends CommonDBTM {
          echo "<form method='post' action='$target'>";
          echo "<input type='hidden' name='itemtype' value='$itemtype'>";
          echo "<input type='hidden' name='users_id' value='$IDuser'>";
-         echo "<select name='num'>";
-         $first_group = true;
-         $searchopt   = Search::getCleanedOptions($itemtype);
-
+         $group  = '';
+         $values = [];
          foreach ($searchopt as $key => $val) {
             if (!is_array($val)) {
-               if (!$first_group) {
-                  echo "</optgroup>\n";
-               } else {
-                  $first_group = false;
-               }
-               echo "<optgroup label=\"$val\">";
-
-            } else if ($key!=1 && !in_array($key,$already_added)) {
-               echo "<option value='$key'>".$val["name"]."</option>";
+               $group = $val;
+            } else if (count($val) === 1) {
+               $group = $val['name'];
+            } else if ($key != 1
+                       && !in_array($key, $already_added)
+                       && (!isset($val['nodisplay']) || !$val['nodisplay'])) {
+               $values[$group][$key] = $val["name"];
             }
          }
-
-         if (!$first_group) {
-            echo "</optgroup>\n";
+         if ($values) {
+            Dropdown::showFromArray('num', $values);
+            echo "<span class='small_space'>";
+            echo "<input type='submit' name='add' value=\""._sx('button', 'Add')."\" class='submit'>";
+            echo "</span>";
          }
-
-         echo "</select><span class='small_space'>";
-         echo "<input type='submit' name='add' value=\"".$LANG['buttons'][8]."\" class='submit'>";
-         echo "</span>";
          Html::closeForm();
          echo "</td></tr>";
       }
@@ -446,7 +495,7 @@ class DisplayPreference extends CommonDBTM {
       if (Session::isMultiEntitiesMode()
           && (isset($CFG_GLPI["union_search_type"][$itemtype])
               || ($item && $item->maybeRecursive())
-              || count($_SESSION["glpiactiveentities"])>1)
+              || (count($_SESSION["glpiactiveentities"]) > 1))
           && isset($searchopt[80])) {
 
          echo "<tr class='tab_bg_2'>";
@@ -458,24 +507,25 @@ class DisplayPreference extends CommonDBTM {
       $i = 0;
 
       if ($numrows) {
-         while ($data=$DB->fetch_array($result)) {
+         while ($data=$DB->fetch_assoc($result)) {
 
-            if ($data["num"]!=1 && isset($searchopt[$data["num"]])) {
+            if (($data["num"] != 1)
+                && isset($searchopt[$data["num"]])) {
 
                echo "<tr class='tab_bg_2'><td class='center' width='50%'>";
                echo $searchopt[$data["num"]]["name"];
                echo "</td>";
 
                if ($global_write) {
-                  if ($i!=0) {
+                  if ($i != 0) {
                      echo "<td class='center middle'>";
                      echo "<form method='post' action='$target'>";
                      echo "<input type='hidden' name='id' value='".$data["id"]."'>";
                      echo "<input type='hidden' name='users_id' value='$IDuser'>";
                      echo "<input type='hidden' name='itemtype' value='$itemtype'>";
-                     echo "<input type='image' name='up' value=\"".$LANG['buttons'][24]."\" src='".
-                            $CFG_GLPI["root_doc"]."/pics/puce-up2.png' alt=\"".
-                            $LANG['buttons'][24]."\"  title=\"".$LANG['buttons'][24]."\">";
+                     echo "<button type='submit' name='up'".
+                         " title=\"".__s('Bring up')."\"".
+                         " class='unstyled pointer'><i class='fa fa-arrow-up'></i></button>";
                      Html::closeForm();
                      echo "</td>";
 
@@ -483,15 +533,15 @@ class DisplayPreference extends CommonDBTM {
                      echo "<td>&nbsp;</td>\n";
                   }
 
-                  if ($i!=$numrows-1) {
+                  if ($i != ($numrows-1)) {
                      echo "<td class='center middle'>";
                      echo "<form method='post' action='$target'>";
                      echo "<input type='hidden' name='id' value='".$data["id"]."'>";
                      echo "<input type='hidden' name='users_id' value='$IDuser'>";
                      echo "<input type='hidden' name='itemtype' value='$itemtype'>";
-                     echo "<input type='image' name='down' value=\"".$LANG['buttons'][25]."\" src='".
-                            $CFG_GLPI["root_doc"]."/pics/puce-down2.png' alt=\"".
-                            $LANG['buttons'][25]."\" title=\"".$LANG['buttons'][25]."\">";
+                     echo "<button type='submit' name='down'".
+                         " title=\"".__s('Bring down')."\"".
+                         " class='unstyled pointer'><i class='fa fa-arrow-down'></i></button>";
                      Html::closeForm();
                      echo "</td>";
 
@@ -504,9 +554,9 @@ class DisplayPreference extends CommonDBTM {
                   echo "<input type='hidden' name='id' value='".$data["id"]."'>";
                   echo "<input type='hidden' name='users_id' value='$IDuser'>";
                   echo "<input type='hidden' name='itemtype' value='$itemtype'>";
-                  echo "<input type='image' name='delete' value=\"".$LANG['buttons'][6]."\" src='".
-                         $CFG_GLPI["root_doc"]."/pics/puce-delete2.png' alt=\"".
-                         $LANG['buttons'][6]."\" title=\"".$LANG['buttons'][6]."\">";
+                  echo "<button type='submit' name='purge'".
+                         " title=\""._sx('button', 'Delete permanently')."\"".
+                         " class='unstyled pointer'><i class='fa fa-times-circle'></i></button>";
                   Html::closeForm();
                   echo "</td>\n";
                }
@@ -527,7 +577,7 @@ class DisplayPreference extends CommonDBTM {
     * @param $users_id integer user ID
    **/
    static function showForUser($users_id) {
-      global $DB, $LANG;
+      global $DB;
 
       $url = Toolbox::getItemTypeFormURL(__CLASS__);
 
@@ -538,30 +588,48 @@ class DisplayPreference extends CommonDBTM {
                 GROUP BY `itemtype`";
 
       $req = $DB->request($query);
-      if ($req->numrows()>0) {
-         echo "<form name='formprefs' id='formprefs' action='$url' method='post'>";
-         echo "<input type='hidden' name='users_id' value='$users_id'>";
-         echo "<table class='tab_cadre_fixe'>";
+      if ($req->numrows() > 0) {
+         $rand = mt_rand();
+         echo "<div class='spaced'>";
+         Html::openMassiveActionsForm('mass'.__CLASS__.$rand);
+         $massiveactionparams = ['width'            => 400,
+                           'height'           => 200,
+                           'container'        => 'mass'.__CLASS__.$rand,
+                           'specific_actions' => [__CLASS__.MassiveAction::CLASS_ACTION_SEPARATOR.'delete_for_user'
+                                                       => _x('button', 'Delete permanently')],
+                           'extraparams'      => ['massive_action_fields' => ['users_id']]];
 
+         Html::showMassiveActions($massiveactionparams);
+
+         echo Html::hidden('users_id', ['value'                 => $users_id,
+                                             'data-glpicore-ma-tags' => 'common']);
+         echo "<table class='tab_cadre_fixe'>";
+         echo "<tr>";
+         echo "<th width='10'>";
+         Html::checkAllAsCheckbox('mass'.__CLASS__.$rand);
+         echo "</th>";
+         echo "<th colspan='2'>".__('Type')."</th></tr>";
          foreach ($req as $data) {
             echo "<tr class='tab_bg_1'><td width='10'>";
-            echo "<input  type='checkbox' name='itemtype[".$data["itemtype"]."]' value='1'></td>";
+            Html::showMassiveActionCheckBox(__CLASS__, $data["itemtype"]);
+            echo "</td>";
             if ($item = getItemForItemtype($data["itemtype"])) {
-               $name = $item->getTypeName();
+               $name = $item->getTypeName(1);
             } else {
                $name = $data["itemtype"];
             }
-            echo "<td>$name</td><td class='right'>".$data['nb']."</td>";
+            echo "<td>$name</td><td class='numeric'>".$data['nb']."</td>";
             echo "</tr>";
          }
          echo "</table>";
-         Html::openArrowMassives('formprefs', true);
-         Html::closeArrowMassives(array('delete_for_user' => $LANG['buttons'][6]));
+         $massiveactionparams['ontop'] = false;
+         Html::showMassiveActions($massiveactionparams);
          Html::closeForm();
+         echo "</div>";
 
       } else {
          echo "<table class='tab_cadre_fixe'>";
-         echo "<tr class='tab_bg_2'><td class='b center'>".$LANG['search'][15]."</td></tr>";
+         echo "<tr class='tab_bg_2'><td class='b center'>".__('No item found')."</td></tr>";
          echo "</table>";
       }
    }
@@ -577,31 +645,29 @@ class DisplayPreference extends CommonDBTM {
    }
 
 
-   function defineTabs($options=array()) {
-      global $LANG;
+   function defineTabs($options = []) {
 
-      $ong = array();
+      $ong = [];
       $this->addStandardTab(__CLASS__, $ong, $options);
       $ong['no_all_tab'] = true;
       return $ong;
    }
 
 
-   function getTabNameForItem(CommonGLPI $item, $withtemplate=0) {
-      global $LANG;
+   function getTabNameForItem(CommonGLPI $item, $withtemplate = 0) {
 
       switch ($item->getType()) {
          case 'Preference' :
-            if (Session::haveRight('search_config', 'w')) {
-               return $LANG['central'][12];
+            if (Session::haveRight(self::$rightname, self::PERSONAL)) {
+               return __('Personal View');
             }
             break;
 
          case __CLASS__:
-            $ong = array();
-            $ong[1] = $LANG['central'][13];  // view group
-            if (Session::haveRight('search_config', 'w')) {
-               $ong[2] = $LANG['central'][12]; // view personnal
+            $ong = [];
+            $ong[1] = __('Global View');
+            if (Session::haveRight(self::$rightname, self::PERSONAL)) {
+               $ong[2] = __('Personal View');
             }
             return $ong;
       }
@@ -609,8 +675,7 @@ class DisplayPreference extends CommonDBTM {
    }
 
 
-   static function displayTabContentForItem(CommonGLPI $item, $tabnum=1, $withtemplate=0) {
-      global $CFG_GLPI;
+   static function displayTabContentForItem(CommonGLPI $item, $tabnum = 1, $withtemplate = 0) {
 
       switch ($item->getType()) {
          case 'Preference' :
@@ -620,17 +685,34 @@ class DisplayPreference extends CommonDBTM {
          case __CLASS__ :
             switch ($tabnum) {
                case 1 :
-                  $item->showFormGlobal($_POST['target'], $_POST["displaytype"]);
+                  $item->showFormGlobal($_GET['_target'], $_GET["displaytype"]);
                   return true;
 
                case 2 :
-                  Session::checkRight('search_config', 'w');
-                  $item->showFormPerso($_POST['target'], $_POST["displaytype"]);
+                  Session::checkRight(self::$rightname, self::PERSONAL);
+                  $item->showFormPerso($_GET['_target'], $_GET["displaytype"]);
                   return true;
             }
       }
       return false;
    }
-}
 
-?>
+
+   /**
+    * @since version 0.85
+    *
+    * @see commonDBTM::getRights()
+   **/
+   function getRights($interface = 'central') {
+
+      //TRANS: short for : Search result user display
+      $values[self::PERSONAL]  = ['short' => __('User display'),
+                                       'long'  => __('Search result user display')];
+      //TRANS: short for : Search result default display
+      $values[self::GENERAL]  =  ['short' => __('Default display'),
+                                       'long'  => __('Search result default display')];
+
+      return $values;
+   }
+
+}
