@@ -1299,9 +1299,9 @@ class MailCollector  extends CommonDBTM {
 
             $text = imap_fetchbody($stream, $uid, $part_number, FT_UID);
 
-            if ($structure->encoding == 3) {
+            if ($structure->encoding == ENCBASE64) {
                $text =  imap_base64($text);
-            } else if ($structure->encoding == 4) {
+            } else if ($structure->encoding == ENCQUOTEDPRINTABLE) {
                $text =  imap_qprint($text);
             }
 
@@ -1325,7 +1325,7 @@ class MailCollector  extends CommonDBTM {
             return $text;
          }
 
-         if ($structure->type == 1) { /* multipart */
+         if ($structure->type == TYPEMULTIPART) {
             $prefix = "";
 
             foreach ($structure->parts as $index => $sub_structure) {
@@ -1371,19 +1371,19 @@ class MailCollector  extends CommonDBTM {
 
       if ($message = imap_fetchbody($this->marubox, $uid, $part, FT_UID)) {
          switch ($structure->encoding) {
-            case 1 :
+            case ENC8BIT :
                $message = imap_8bit($message);
                break;
 
-            case 2 :
+            case ENCBINARY :
                $message = imap_binary($message);
                break;
 
-            case 3 :
+            case ENCBASE64 :
                $message = imap_base64($message);
                break;
 
-            case 4 :
+            case ENCQUOTEDPRINTABLE :
                $message = quoted_printable_decode($message);
                break;
          }
@@ -1407,9 +1407,9 @@ class MailCollector  extends CommonDBTM {
    **/
    function getRecursiveAttached($uid, $path, $maxsize, $structure, $part = "") {
 
-      if ($structure->type == 1) { // multipart
+      if ($structure->type == TYPEMULTIPART) {
          foreach ($structure->parts as $index => $sub_structure) {
-            $this->getRecursiveAttached($mid, $path, $maxsize, $sub_structure,
+            $this->getRecursiveAttached($uid, $path, $maxsize, $sub_structure,
                                         ($part ? $part.".".($index+1) : ($index+1)));
          }
 
@@ -1421,9 +1421,9 @@ class MailCollector  extends CommonDBTM {
 
          $filename = '';
 
+         // get filename of attachment if present
+         // if there are any dparameters present in this part
          if ($structure->ifdparameters) {
-            // get filename of attachment if present
-            // if there are any dparameters present in this part
             if (count($structure->dparameters) > 0) {
                foreach ($structure->dparameters as $dparam) {
                   if ((Toolbox::strtoupper($dparam->attribute) == 'NAME')
@@ -1434,12 +1434,10 @@ class MailCollector  extends CommonDBTM {
             }
          }
 
-         //if no filename found
+         // if there are any parameters present in this part
          if (empty($filename)
              && $structure->ifparameters) {
-
-            // if there are any parameters present in this part
-            if (count($structure->parameters)>0) {
+            if (count($structure->parameters) > 0) {
                foreach ($structure->parameters as $param) {
                   if ((Toolbox::strtoupper($param->attribute) == 'NAME')
                       || (Toolbox::strtoupper($param->attribute) == 'FILENAME')) {
@@ -1449,15 +1447,23 @@ class MailCollector  extends CommonDBTM {
             }
          }
 
+         // part come without correct filename in [d]parameters - generate trivial one
+         // (inline images case for example)
+         if ((empty($filename) || !Document::isValidDoc($filename))
+             && $structure->type != TYPETEXT
+             && $structure->type != TYPEMULTIPART
+             && $structure->type != TYPEMESSAGE
+             && $structure->subtype) {
+            $tmp_filename = "doc_$part.".$structure->subtype;
+            if (Document::isValidDoc($tmp_filename)) {
+               $filename = $tmp_filename;
+            }
+         }
+
+         // Embeded email comes without filename - try to get "Subject:" or generate trivial one
          if (empty($filename)
-             && ($structure->type == 5)
+             && $structure->type == TYPEMESSAGE
              && $structure->subtype) {
-            // Embeded image come without filename - generate trivial one
-            $filename = "image_$part.".$structure->subtype;
-         } else if (empty($filename)
-                    && ($structure->type == 2)
-                    && $structure->subtype) {
-            // Embeded email comes without filename - try to get "Subject:" or generate trivial one
             $filename = "msg_$part.EML"; // default trivial one :)!
             if (($message = $this->getDecodedFetchbody($structure, $uid, $part))
                     && (preg_match( "/Subject: *([^\r\n]*)/i", $message, $matches))) {
@@ -1501,12 +1507,12 @@ class MailCollector  extends CommonDBTM {
             return false;
          }
 
-         if ((($structure->type == 2) && $structure->subtype)
+         if ((($structure->type == TYPEMESSAGE) && $structure->subtype)
              || ($message = $this->getDecodedFetchbody($structure, $uid, $part))) {
             if (file_put_contents($path.$filename, $message)) {
                $this->files[$filename] = $filename;
                // If embeded image, we add a tag
-               if (($structure->type == 5)
+               if (($structure->type == TYPEIMAGE)
                    && $structure->subtype) {
                   end($this->files);
                   $tag = Rule::getUuid();
@@ -1580,6 +1586,12 @@ class MailCollector  extends CommonDBTM {
     * @return Boolean
    **/
    function deleteMails($uid, $folder = '') {
+
+      // Disable move support, POP protocol only has the INBOX folder
+      if (strstr($this->fields['host'], "/pop")) {
+         $folder = '';
+      }
+
       if (!empty($folder) && isset($this->fields[$folder]) && !empty($this->fields[$folder])) {
          $name = mb_convert_encoding($this->fields[$folder], "UTF7-IMAP", "UTF-8");
          if (imap_mail_move($this->marubox, $uid, $name, CP_UID)) {
