@@ -561,7 +561,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
     */
-   final protected function addAdmin() {
+   final public function addAdmin() {
       $eventclass = $this->event;
       $admin_data = $eventclass::getAdminData();
 
@@ -581,7 +581,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
     */
-   protected function addItemAuthor() {
+   public function addItemAuthor() {
       $user = new User();
       if ($this->obj->isField('users_id')
           && $user->getFromDB($this->obj->getField('users_id'))) {
@@ -600,7 +600,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
     */
-   final protected function addItemGroup() {
+   final public function addItemGroup() {
 
       if (!empty($this->target_object)) {
          foreach ($this->target_object as $val) {
@@ -619,7 +619,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
     */
-   final protected function addItemGroupSupervisor() {
+   final public function addItemGroupSupervisor() {
       if (!empty($this->target_object)) {
          foreach ($this->target_object as $val) {
             if ($val->fields['groups_id'] > 0) {
@@ -637,7 +637,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
     */
-   final protected function addItemGroupWithoutSupervisor() {
+   final public function addItemGroupWithoutSupervisor() {
 
       if (!empty($this->target_object)) {
          foreach ($this->target_object as $val) {
@@ -654,7 +654,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
     */
-   final protected function addEntityAdmin() {
+   final public function addEntityAdmin() {
       $eventclass = $this->event;
       $admins_data = $eventclass::getEntityAdminsData($this->entity);
 
@@ -679,7 +679,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
    **/
-   final protected function addForGroup($manager, $group_id) {
+   final public function addForGroup($manager, $group_id) {
       global $DB;
 
       // members/managers of the group allowed on object entity
@@ -704,7 +704,7 @@ class NotificationTarget extends CommonDBChild {
    }
 
 
-   final protected function getDistinctUserSql() {
+   final public function getDistinctUserSql() {
 
       return  "SELECT DISTINCT `glpi_users`.`id` AS users_id,
                                `glpi_users`.`language` AS language";
@@ -765,7 +765,7 @@ class NotificationTarget extends CommonDBChild {
    /**
     * @param $entity
    **/
-   final protected function addGroupsToTargets($entity) {
+   final public function addGroupsToTargets($entity) {
       global $DB;
 
       // Filter groups which can be notified and have members (as notifications are sent to members)
@@ -802,7 +802,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
    **/
-   protected function addNotificationTargets($entity) {
+   public function addNotificationTargets($entity) {
 
       if (Session::haveRight("config", UPDATE)) {
          $this->addTarget(Notification::GLOBAL_ADMINISTRATOR, __('Administrator'));
@@ -822,7 +822,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
     */
-   protected function addAdditionalTargets($event = '') {
+   public function addAdditionalTargets($event = '') {
    }
 
 
@@ -834,7 +834,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
    **/
-   protected function addSpecificTargets($data, $options) {
+   public function addSpecificTargets($data, $options) {
    }
 
 
@@ -860,7 +860,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
    **/
-   final protected function addUserByField($field, $search_in_object = false) {
+   final public function addUserByField($field, $search_in_object = false) {
       global $DB;
 
       $id = [];
@@ -893,7 +893,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
    **/
-   final protected function addItemTechnicianInCharge() {
+   final public function addItemTechnicianInCharge() {
       $this->addUserByField('users_id_tech', true);
    }
 
@@ -903,7 +903,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
     */
-   final protected function addItemGroupTechInCharge() {
+   final public function addItemGroupTechInCharge() {
       if (!empty($this->target_object)) {
          foreach ($this->target_object as $val) {
             if ($val->fields['groups_id_tech'] > 0) {
@@ -919,7 +919,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
    **/
-   final protected function addItemOwner() {
+   final public function addItemOwner() {
       $this->addUserByField('users_id', true);
    }
 
@@ -931,7 +931,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
     */
-   final protected function addForProfile($profiles_id) {
+   final public function addForProfile($profiles_id) {
       global $DB;
 
       $query = $this->getDistinctUserSql().",
@@ -951,7 +951,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return array [email => sender address, name => sender name]
    **/
-   function getSender() {
+   public function getSender() {
       global $CFG_GLPI;
 
       $sender = [
@@ -992,7 +992,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return the reply to address
    **/
-   final public function getReplyTo($options = []) {
+   public function getReplyTo($options = []) {
       global $DB, $CFG_GLPI;
 
       //If the entity administrator's address is defined, return it
@@ -1001,12 +1001,12 @@ class NotificationTarget extends CommonDBChild {
 
          if (NotificationMailing::isUserAddressValid($data['admin_reply'])) {
             return ['email' => $data['admin_reply'],
-                         'name'  => $data['admin_reply_name']];
+                    'name'  => $data['admin_reply_name']];
          }
       }
       //Entity admin is not defined, return the global admin's address
       return ['email' => $CFG_GLPI['admin_reply'],
-                   'name'  => $CFG_GLPI['admin_reply_name']];
+              'name'  => $CFG_GLPI['admin_reply_name']];
    }
 
 
@@ -1112,7 +1112,7 @@ class NotificationTarget extends CommonDBChild {
     *
     * @return void
    **/
-   protected function addDataForTemplate($event, $options = []) {
+   public function addDataForTemplate($event, $options = []) {
    }
 
 
@@ -1131,7 +1131,7 @@ class NotificationTarget extends CommonDBChild {
    }
 
 
-   protected function getProfileJoinSql() {
+   public function getProfileJoinSql() {
 
       return " INNER JOIN `glpi_profiles_users`
                      ON (`glpi_profiles_users`.`users_id` = `glpi_users`.`id` ".
@@ -1325,7 +1325,7 @@ class NotificationTarget extends CommonDBChild {
                } else {
                   echo "&nbsp;";
                }
-               echo "</td><td>".Notification::getMode($notif->getField('mode'));
+               echo "</td><td>".Notification_NotificationTemplate::getMode($notif->getField('mode'));
                echo "</td><td>".NotificationEvent::getEventName($itemtype,
                                                                 $notif->getField('event'));
                echo "</td>".
