@@ -1,81 +1,69 @@
 <?php
-
-
-/*
- * @version $Id: ruledictionnarysoftwarecollection.class.php 20130 2013-02-04 16:55:15Z moyo $
- -------------------------------------------------------------------------
- GLPI - Gestionnaire Libre de Parc Informatique
- Copyright (C) 2003-2013 by the INDEPNET Development Team.
-
- http://indepnet.net/   http://glpi-project.org
- -------------------------------------------------------------------------
-
- LICENSE
-
- This file is part of GLPI.
-
- GLPI is free software; you can redistribute it and/or modify
- it under the terms of the GNU General Public License as published by
- the Free Software Foundation; either version 2 of the License, or
- (at your option) any later version.
-
- GLPI is distributed in the hope that it will be useful,
- but WITHOUT ANY WARRANTY; without even the implied warranty of
- MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- GNU General Public License for more details.
-
- You should have received a copy of the GNU General Public License
- along with GLPI. If not, see <http://www.gnu.org/licenses/>.
- --------------------------------------------------------------------------
+/**
+ * ---------------------------------------------------------------------
+ * GLPI - Gestionnaire Libre de Parc Informatique
+ * Copyright (C) 2015-2017 Teclib' and contributors.
+ *
+ * http://glpi-project.org
+ *
+ * based on GLPI - Gestionnaire Libre de Parc Informatique
+ * Copyright (C) 2003-2014 by the INDEPNET Development Team.
+ *
+ * ---------------------------------------------------------------------
+ *
+ * LICENSE
+ *
+ * This file is part of GLPI.
+ *
+ * GLPI is free software; you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License as published by
+ * the Free Software Foundation; either version 2 of the License, or
+ * (at your option) any later version.
+ *
+ * GLPI is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with GLPI. If not, see <http://www.gnu.org/licenses/>.
+ * ---------------------------------------------------------------------
  */
 
-// ----------------------------------------------------------------------
-// Original Author of file: Walid Nouh
-// Purpose of file:
-// ----------------------------------------------------------------------
+/** @file
+* @brief
+*/
 if (!defined('GLPI_ROOT')) {
-   die("Sorry. You can't access directly to this file");
+   die("Sorry. You can't access this file directly");
 }
 
-class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
+class RuleDictionnarySoftwareCollection extends RuleCollection {
    // From RuleCollection
 
    public $stop_on_first_match = true;
-   public $right               = 'rule_dictionnary_software';
+   public $can_replay_rules    = true;
    public $menu_type           = 'dictionnary';
    public $menu_option         = 'software';
 
+   static $rightname           = 'rule_dictionnary_software';
 
    /**
-    * Constructor
+    * @see RuleCollection::getTitle()
    **/
-   function __construct() {
-
-      //Init cache system values
-      $this->initCache("glpi_rulecachesoftwares", array("name"         => "old_value",
-                                                        "manufacturer" => "manufacturer",
-                                                        "entities_id"  => "entities_id"),
-                       array("name"                => "new_value",
-                             "version"             => "version",
-                             "manufacturer"        => "new_manufacturer",
-                             "is_helpdesk_visible" => "is_helpdesk_visible",
-                             "_ignore_ocs_import"  => "ignore_ocs_import",
-                             "new_entities_id"     => "new_entities_id"));
-   }
-
-
    function getTitle() {
-      global $LANG;
-
-      return $LANG['rulesengine'][35];
+      //TRANS: software in plural
+      return __('Dictionnary of software');
    }
 
 
-   function cleanTestOutputCriterias($output) {
+   /**
+    * @see RuleCollection::cleanTestOutputCriterias()
+   **/
+   function cleanTestOutputCriterias(array $output) {
 
       //If output array contains keys begining with _ : drop it
       foreach ($output as $criteria => $value) {
-         if ($criteria[0] == '_' && $criteria != '_ignore_ocs_import') {
+         if (($criteria[0] == '_') && ($criteria != '_ignore_import')) {
             unset ($output[$criteria]);
          }
       }
@@ -83,26 +71,34 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
    }
 
 
+   /**
+    * @see RuleCollection::warningBeforeReplayRulesOnExistingDB()
+   **/
    function warningBeforeReplayRulesOnExistingDB($target) {
-      global $LANG, $CFG_GLPI;
+      global $CFG_GLPI;
 
       echo "<form name='testrule_form' id='softdictionnary_confirmation' method='post' action=\"" .
              $target . "\">\n";
       echo "<div class='center'>";
       echo "<table class='tab_cadre_fixe'>";
-      echo "<tr><th colspan='2' class='b'>" . $LANG['rulesengine'][92] . "</th</tr>\n";
+      echo "<tr><th colspan='2' class='b'>" .
+            __('Warning before running rename based on the dictionary rules') . "</th></tr>\n";
       echo "<tr><td class='tab_bg_2 center'>";
       echo "<img src=\"" . $CFG_GLPI["root_doc"] . "/pics/warning.png\"></td>";
-      echo "<td class='tab_bg_2 center'>" . $LANG['rulesengine'][93] . "</td></tr>\n";
-      echo "<tr><th colspan='2' class='b'>" . $LANG['rulesengine'][95] . "</th</tr>\n";
-      echo "<tr><td class='tab_bg_2 center'>" . $LANG['rulesengine'][96] . "</td>";
+      echo "<td class='tab_bg_2 center'>" .
+            __('Warning! This operation can put merged software in the dustbin.<br>Sure to notify your users.').
+           "</td></tr>\n";
+      echo "<tr><th colspan='2' class='b'>" . __('Manufacturer choice') . "</th></tr>\n";
+      echo "<tr><td class='tab_bg_2 center'>" .
+            __('Replay dictionary rules for manufacturers (----- = All)') . "</td>";
       echo "<td class='tab_bg_2 center'>";
-      Dropdown::show('Manufacturer', array('name' => 'manufacturer'));
+      Manufacturer::dropdown(['name' => 'manufacturer']);
       echo "</td></tr>\n";
 
       echo "<tr><td class='tab_bg_2 center' colspan='2'>";
-      echo "<input type='submit' name='replay_rule' value=\"".$LANG['buttons'][2]."\" class='submit'>";
-      echo "<input type='hidden' name='replay_confirm' value='replay_confirm'";
+      echo "<input type='submit' name='replay_rule' value=\""._sx('button', 'Post')."\"
+             class='submit'>";
+      echo "<input type='hidden' name='replay_confirm' value='replay_confirm'>";
       echo "</td></tr>";
       echo "</table>\n";
       echo "</div>\n";
@@ -111,7 +107,10 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
    }
 
 
-   function replayRulesOnExistingDB($offset=0, $maxtime=0, $items=array(), $params=array()) {
+   /**
+    * @see RuleCollection::replayRulesOnExistingDB()
+   **/
+   function replayRulesOnExistingDB($offset = 0, $maxtime = 0, $items = [], $params = []) {
       global $DB;
 
       if (isCommandLine()) {
@@ -125,17 +124,18 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
          $sql = "SELECT DISTINCT `glpi_softwares`.`name`,
                         `glpi_manufacturers`.`name` AS manufacturer,
                         `glpi_softwares`.`manufacturers_id` AS manufacturers_id,
-                        `glpi_softwares`.`entities_id` AS entities_id
+                        `glpi_softwares`.`entities_id` AS entities_id,
+                        `glpi_softwares`.`is_helpdesk_visible` AS helpdesk
                  FROM `glpi_softwares`
                  LEFT JOIN `glpi_manufacturers`
                      ON (`glpi_manufacturers`.`id` = `glpi_softwares`.`manufacturers_id`)";
 
-         // Do not replay on trash and templates
+         // Do not replay on dustbin and templates
          $sql .= "WHERE `glpi_softwares`.`is_deleted` = '0'
                         AND `glpi_softwares`.`is_template` = '0' ";
 
-         if (isset($params['manufacturer']) && $params['manufacturer'] > 0) {
-            $sql .= " AND `manufacturers_id` = '" . $params['manufacturer'] . "'";
+         if (isset($params['manufacturer']) && $params['manufacturer']) {
+            $sql .= " AND `glpi_softwares`.`manufacturers_id` = '" . $params['manufacturer'] . "'";
          }
          if ($offset) {
             $sql .= " LIMIT " . intval($offset) . ",999999999";
@@ -143,13 +143,13 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
 
          $res  = $DB->query($sql);
          $nb   = $DB->numrows($res) + $offset;
-         $step = ($nb > 1000 ? 50 : ($nb > 20 ? floor($DB->numrows($res) / 20) : 1));
+         $step = (($nb > 1000) ? 50 : (($nb > 20) ? floor($DB->numrows($res) / 20) : 1));
 
-         while ($input = $DB->fetch_array($res)) {
+         while ($input = $DB->fetch_assoc($res)) {
             if (!($i % $step)) {
                if (isCommandLine()) {
-                  echo date("H:i:s") . " replayRulesOnExistingDB : $i/$nb (" .
-                       round(memory_get_usage() / (1024 * 1024), 2) . " Mo)\n";
+                  printf(__('%1$s - replay rules on existing database: %2$s/%3$s (%4$s Mio)')."\n",
+                      date("H:i:s"), $i, $nb, round(memory_get_usage() / (1024 * 1024), 2));
                } else {
                   Html::changeProgressBarPosition($i, $nb, "$i / $nb");
                }
@@ -157,20 +157,22 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
 
             //If manufacturer is set, then first run the manufacturer's dictionnary
             if (isset($input["manufacturer"])) {
-               $input["manufacturer"] = Manufacturer::processName($input["manufacturer"]);
+               $input["manufacturer"] = Manufacturer::processName(addslashes($input["manufacturer"]));
             }
 
             //Replay software dictionnary rules
-            $input    = Toolbox::addslashes_deep($input);
-            $res_rule = $this->processAllRules($input, array(), array());
-            $res_rule = Toolbox::addslashes_deep($res_rule);
+            $res_rule = $this->processAllRules($input, [], []);
 
-            if ((isset($res_rule["name"]) && $res_rule["name"] != $input["name"])
-                || (isset($res_rule["version"]) && $res_rule["version"] != '')
+            if ((isset($res_rule["name"]) && (strtolower($res_rule["name"]) != strtolower($input["name"])))
+                || (isset($res_rule["version"]) && ($res_rule["version"] != ''))
                 || (isset($res_rule['new_entities_id'])
-                    && $res_rule['new_entities_id'] != $input['entities_id'])) {
+                    && ($res_rule['new_entities_id'] != $input['entities_id']))
+                || (isset($res_rule['is_helpdesk_visible'])
+                    && ($res_rule['is_helpdesk_visible'] != $input['helpdesk']))
+                || (isset($res_rule['manufacturer'])
+                    && ($res_rule['manufacturer'] != $input['manufacturer']))) {
 
-               $IDs = array();
+               $IDs = [];
                //Find all the softwares in the database with the same name and manufacturer
                $sql = "SELECT `id`
                        FROM `glpi_softwares`
@@ -180,7 +182,7 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
 
                if ($DB->numrows($res_soft) > 0) {
                   //Store all the software's IDs in an array
-                  while ($result = $DB->fetch_array($res_soft)) {
+                  while ($result = $DB->fetch_assoc($res_soft)) {
                      $IDs[] = $result["id"];
                   }
                   //Replay dictionnary on all the softwares
@@ -190,14 +192,14 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
             $i++;
             if ($maxtime) {
                $crt = explode(" ", microtime());
-               if ($crt[0] + $crt[1] > $maxtime) {
+               if (($crt[0] + $crt[1]) > $maxtime) {
                   break;
                }
             }
          } // each distinct software
 
          if (isCommandLine()) {
-            echo "replayRulesOnExistingDB : $i/$nb               \n";
+            printf(__('Replay rules on existing database: %1$s/%2$s')."   \n", $i, $nb);
          } else {
             Html::changeProgressBarPosition($i, $nb, "$i / $nb");
          }
@@ -208,26 +210,26 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
       }
 
       if (isCommandLine()) {
-         echo "replayRulesOnExistingDB ended : " . date("r") . "\n";
+         printf(__('Replay rules on existing database ended on %s')."\n", date("r"));
       }
 
-      return ($i == $nb ? -1 : $i);
+      return (($i == $nb) ? -1 : $i);
    }
 
 
    /**
     * Replay dictionnary on several softwares
     *
-    * @param $IDs array of software IDs to replay
-    * @param $res_rule array of rule results
+    * @param $IDs       array of software IDs to replay
+    * @param $res_rule  array of rule results
     *
     * @return Query result handler
    **/
-   function replayDictionnaryOnSoftwaresByID($IDs, $res_rule=array()) {
+   function replayDictionnaryOnSoftwaresByID(array $IDs, $res_rule = []) {
       global $DB;
 
-      $new_softs  = array();
-      $delete_ids = array();
+      $new_softs  = [];
+      $delete_ids = [];
 
       foreach ($IDs as $ID) {
          $res_soft = $DB->query("SELECT `gs`.`id`,
@@ -241,7 +243,7 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
                                        AND `gs`.`id` = '$ID'");
 
          if ($DB->numrows($res_soft)) {
-            $soft = $DB->fetch_array($res_soft);
+            $soft = $DB->fetch_assoc($res_soft);
             //For each software
             $this->replayDictionnaryOnOneSoftware($new_softs, $res_rule, $ID,
                                                   (isset($res_rule['new_entities_id'])
@@ -261,32 +263,33 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
    /**
     * Replay dictionnary on one software
     *
-    * @param $new_softs array containing new softwares already computed
-    * @param $res_rule array of rule results
-    * @param $ID ID of the software
-    * @param $entity working entity ID
-    * @param $name softwrae name
-    * @param $manufacturer manufacturer ID
-    * @param $soft_ids array containing replay software need to be trashed
+    * @param &$new_softs      array containing new softwares already computed
+    * @param $res_rule        array of rule results
+    * @param $ID                    ID of the software
+    * @param $entity                working entity ID
+    * @param $name                  softwrae name
+    * @param $manufacturer          manufacturer name
+    * @param &$soft_ids       array containing replay software need to be dustbined
    **/
-   function replayDictionnaryOnOneSoftware(& $new_softs, $res_rule, $ID, $entity, $name,
-                                           $manufacturer, & $soft_ids) {
+   function replayDictionnaryOnOneSoftware(array &$new_softs, array $res_rule, $ID, $entity, $name,
+                                           $manufacturer, array &$soft_ids) {
       global $DB;
 
       $input["name"]         = $name;
       $input["manufacturer"] = $manufacturer;
       $input["entities_id"]  = $entity;
-      $input                 = Toolbox::addslashes_deep($input);
 
       if (empty($res_rule)) {
-         $res_rule = $this->processAllRules($input, array(), array());
-         $res_rule = Toolbox::addslashes_deep($res_rule);
+         $res_rule = $this->processAllRules($input, [], []);
       }
       $soft = new Software();
+      if (isset($res_rules['_ignore_import']) && ($res_rules['_ignore_import'] == 1)) {
+          $soft->putInTrash($ID, __('Software deleted by GLPI dictionary rules'));
+          return;
+      }
 
-      ///TODO walid : check parentheses + params for getSonsOf + comment (parent or child ?)
       //Software's name has changed or entity
-      if ((isset($res_rule["name"]) && $res_rule["name"] != $name)
+      if ((isset($res_rule["name"]) && (strtolower($res_rule["name"]) != strtolower($name)))
             //Entity has changed, and new entity is a parent of the current one
           || (!isset($res_rule["name"])
               && isset($res_rule['new_entities_id'])
@@ -296,19 +299,20 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
          if (isset($res_rule["name"])) {
             $new_name = $res_rule["name"];
          } else {
-            $new_name = $name;
+            $new_name = addslashes($name);
          }
 
-         if (isset($res_rule["manufacturer"])) {
-            $manufacturer = Dropdown::getDropdownName("glpi_manufacturers",
-                                                      $res_rule["manufacturer"]);
+         if (isset($res_rule["manufacturer"]) && $res_rule["manufacturer"]) {
+            $manufacturer = $res_rule["manufacturer"];
+         } else {
+            $manufacturer = addslashes($manufacturer);
          }
 
          //New software not already present in this entity
          if (!isset($new_softs[$entity][$new_name])) {
-            // create new software or restore it from trash
-            $new_software_id = $soft->addOrRestoreFromTrash($new_name, $manufacturer,
-                                                            $entity, '', true);
+            // create new software or restore it from dustbin
+            $new_software_id               = $soft->addOrRestoreFromTrash($new_name, $manufacturer,
+                                                                          $entity, '', true);
             $new_softs[$entity][$new_name] = $new_software_id;
          } else {
             $new_software_id = $new_softs[$entity][$new_name];
@@ -319,8 +323,9 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
       } else {
          $new_software_id = $ID;
          $res_rule["id"]  = $ID;
-         if (isset($res_rule["manufacturer"])) {
-            $res_rule["manufacturers_id"] = $res_rule["manufacturer"];
+         if (isset($res_rule["manufacturer"]) && $res_rule["manufacturer"]) {
+            $res_rule["manufacturers_id"] = Dropdown::importExternal('Manufacturer',
+                                                                     $res_rule["manufacturer"]);
             unset($res_rule["manufacturer"]);
          }
          $soft->update($res_rule);
@@ -336,7 +341,7 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
                             FROM `glpi_softwareversions`
                             WHERE `softwares_id` = '$ID'");
 
-      while ($version = $DB->fetch_array($result)) {
+      while ($version = $DB->fetch_assoc($result)) {
          $input["version"] = addslashes($version["name"]);
          $old_version_name = $input["version"];
 
@@ -345,8 +350,8 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
          } else {
             $new_version_name = $version["name"];
          }
-         if ($ID != $new_software_id
-             || $new_version_name != $old_version_name) {
+         if (($ID != $new_software_id)
+             || ($new_version_name != $old_version_name)) {
             $this->moveVersions($ID, $new_software_id, $version["id"], $old_version_name,
                                 $new_version_name, $entity);
          }
@@ -357,30 +362,30 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
    /**
     * Delete a list of softwares
     *
-    * @param $soft_ids array containing replay software need to be trashed
-   */
-   function putOldSoftsInTrash($soft_ids) {
-      global $DB, $LANG;
+    * @param $soft_ids array containing replay software need to be dustbined
+   **/
+   function putOldSoftsInTrash(array $soft_ids) {
+      global $DB;
 
       if (count($soft_ids) > 0) {
-         $ids = implode("','", $soft_ids);
 
-         //Try to delete all the software that are not used anymore (which means that don't have version associated anymore)
+         //Try to delete all the software that are not used anymore
+         // (which means that don't have version associated anymore)
          $res_countsoftinstall
             = $DB->query("SELECT `glpi_softwares`.`id`,
                                  COUNT(`glpi_softwareversions`.`softwares_id`) AS `cpt`
                           FROM `glpi_softwares`
                           LEFT JOIN `glpi_softwareversions`
                               ON `glpi_softwareversions`.`softwares_id` = `glpi_softwares`.`id`
-                          WHERE `glpi_softwares`.`id` IN ('$ids')
+                          WHERE `glpi_softwares`.`id` IN (".implode(",", $soft_ids).")
                                 AND `is_deleted` = '0'
                           GROUP BY `glpi_softwares`.`id`
                           HAVING `cpt` = '0'
                           ORDER BY `cpt`");
 
          $software = new Software();
-         while ($soft = $DB->fetch_array($res_countsoftinstall)) {
-            $software->putInTrash($soft["id"], $LANG['rulesengine'][87]);
+         while ($soft = $DB->fetch_assoc($res_countsoftinstall)) {
+            $software->putInTrash($soft["id"], __('Software deleted by GLPI dictionary rules'));
          }
       }
    }
@@ -389,17 +394,17 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
    /**
     * Change software's name, and move versions if needed
     *
-    * @param $ID old software ID
-    * @param $new_software_id new software ID
-    * @param $version_id version ID to move
-    * @param $old_version old version name
-    * @param $new_version new version name
-    * @param $entity entity ID
+    * @param $ID                    old software ID
+    * @param $new_software_id       new software ID
+    * @param $version_id            version ID to move
+    * @param $old_version           old version name
+    * @param $new_version           new version name
+    * @param $entity                entity ID
    */
    function moveVersions($ID, $new_software_id, $version_id, $old_version, $new_version, $entity) {
       global $DB;
 
-      $new_versionID = $this->versionExists($new_software_id, $version_id, $new_version);
+      $new_versionID = $this->versionExists($new_software_id, $new_version);
 
       // Do something if it is not the same version
       if ($new_versionID != $version_id) {
@@ -411,6 +416,21 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
                             `softwares_id` = '$new_software_id'
                         WHERE `id` = '$version_id'");
          } else {
+            // Delete software can be in double after update
+            $sql = "SELECT gcs_2.*
+                    FROM `glpi_computers_softwareversions`
+                    LEFT JOIN  `glpi_computers_softwareversions` AS gcs_2
+                       ON `glpi_computers_softwareversions`.`computers_id` = gcs_2.`computers_id`
+                    WHERE `glpi_computers_softwareversions`.`softwareversions_id` = '$new_versionID'
+                          AND gcs_2.`softwareversions_id` = '$version_id'";
+            $res = $DB->query($sql);
+            if ($DB->numrows($res) > 0) {
+               while ($result = $DB->fetch_assoc($res)) {
+                  $DB->query("DELETE FROM `glpi_computers_softwareversions`
+                              WHERE `id` = '".$result['id']."'");
+               }
+            }
+
             //Change ID of the version in glpi_computers_softwareversions
             $DB->query("UPDATE `glpi_computers_softwareversions`
                         SET `softwareversions_id` = '$new_versionID'
@@ -426,7 +446,7 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
                         WHERE `softwareversions_id_use` = '$version_id'");
             //Delete old version
             $old_version = new SoftwareVersion();
-            $old_version->delete(array("id" => $version_id));
+            $old_version->delete(["id" => $version_id]);
          }
       }
    }
@@ -435,29 +455,36 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
    /**
     * Move licenses from a software to another
     *
-    * @param $ID old software ID
-    * @param $new_software_id new software ID
+    * @param $old_software_id    old software ID
+    * @param $new_software_id    new software ID
+    * @return true if move was successful
    **/
-   function moveLicenses($ID, $new_software_id) {
+   function moveLicenses($old_software_id, $new_software_id) {
       global $DB;
 
+      //Return false if one of the 2 softwares doesn't exists
+      if (!countElementsInTable('glpi_softwares', ['id' => $old_software_id])
+         || !countElementsInTable('glpi_softwares', ['id' => $new_software_id])) {
+         return false;
+      }
+
       //Transfer licenses to new software if needed
-      if ($ID != $new_software_id) {
+      if ($old_software_id != $new_software_id) {
          $DB->query("UPDATE `glpi_softwarelicenses`
                      SET `softwares_id` = '$new_software_id'
-                     WHERE `softwares_id` = '$ID'");
+                     WHERE `softwares_id` = '$old_software_id'");
       }
+      return true;
    }
 
 
    /**
     * Check if a version exists
     *
-    * @param $software_id software ID
-    * @param $version_id version ID to search
-    * @param $version version name
+    * @param $software_id  software ID
+    * @param $version      version name
    **/
-   function versionExists($software_id, $version_id, $version) {
+   function versionExists($software_id, $version) {
       global $DB;
 
       //Check if the version exists
@@ -470,5 +497,3 @@ class RuleDictionnarySoftwareCollection extends RuleCachedCollection {
    }
 
 }
-
-?>
\ No newline at end of file
