@@ -314,7 +314,7 @@ class SavedSearch extends CommonDBTM {
 
       $this->fields["users_id"]     = Session::getLoginUserID();
       $this->fields["is_private"]   = 1;
-      $this->fields["is_recursive"] = 0;
+      $this->fields["is_recursive"] = 1;
       $this->fields["entities_id"]  = $_SESSION["glpiactive_entity"];
    }
 
@@ -346,6 +346,7 @@ class SavedSearch extends CommonDBTM {
       $ID = $this->getID();
 
       $this->initForm($ID, $options);
+      $options['formtitle'] = false;
       $this->showFormHeader($options);
 
       if (isset($options['itemtype'])) {
@@ -361,11 +362,15 @@ class SavedSearch extends CommonDBTM {
       }
 
       echo "<tr><th colspan='4'>";
-      if ($ID > 0) {
-         //TRANS: %1$s is the Itemtype name and $2$d the ID of the item
-         printf(__('%1$s - ID %2$d'), $this->getTypeName(1), $ID);
+      if (!isset($options['ajax'])) {
+         if ($ID > 0) {
+            //TRANS: %1$s is the Itemtype name and $2$d the ID of the item
+            printf(__('%1$s - ID %2$d'), $this->getTypeName(1), $ID);
+         } else {
+            echo __('New item');
+         }
       } else {
-         echo __('New item');
+         echo __('New saved search');
       }
       echo "</th></tr>";
 
@@ -385,13 +390,27 @@ class SavedSearch extends CommonDBTM {
       }
       echo "</td></tr>";
 
-      echo "<tr class='tab_bg_2'><td>".__('Visibility')."</td>";
-      echo "<td colspan='3'>";
+      $rand = mt_rand();
+      echo "<tr class='tab_bg_2'><td><label for='dropdown_is_private$rand'>".__('Visibility') . "</label></td>";
       if ($this->canCreate()) {
-         Dropdown::showPrivatePublicSwitch($this->fields["is_private"],
-                                           $this->fields["entities_id"],
-                                           $this->fields["is_recursive"]);
+         echo "<td colspan='3'>";
+         Dropdown::showFromArray(
+            'is_private', [
+               1  => __('Private'),
+               0  => __('Public')
+            ], [
+               'value'  => $this->fields['is_private'],
+               'rand'   => $rand
+            ]
+         );
+         echo "</td></tr>";
+         echo "<tr class='tab_bg_2'><td>".__('Entity')."</td>";
+         echo "</td><td>";
+         Entity::dropdown(['value' => $this->fields["entities_id"]]);
+         echo "</td><td>". __('Child entities')."</td><td>";
+         Dropdown::showYesNo('is_recursive', $this->fields["is_recursive"]);
       } else {
+         echo "<td colspan='3'>";
          if ($this->fields["is_private"]) {
             echo __('Private');
          } else {
@@ -741,15 +760,19 @@ class SavedSearch extends CommonDBTM {
 
       $colspan = 2;
       echo "<table class='tab_cadre_fixehov'>";
-      echo "<tr><th colspan='$colspan' class='private_header'>" .
+      echo "<thead><tr><th colspan='$colspan' class='private_header'>" .
                   sprintf(__('Private %1$s'), $this->getTypeName(count($searches['private']))) .
-           "</th></tr>";
+                  "<i class='toggle fa fa-chevron-circle-up' title='".__('Hide/Show elements')."'></i>" .
+           "</th></tr></thead><tbody>";
       echo $this->displaySavedSearchType($searches['private']);
+      echo "</tbody>";
       if ($this->canView()) {
-         echo "<tr><th colspan='$colspan'>" .
+         echo "<thead><tr><th colspan='$colspan'>" .
                      sprintf(__('Public %1$s'), $this->getTypeName(count($searches['public']))) .
-              "</th></tr>";
+                     "<i class='toggle fa fa-chevron-circle-up' title='".__('Hide/Show elements')."'></i>" .
+              "</th></tr></thead><tbody>";
          echo $this->displaySavedSearchType($searches['public']);
+         echo "</tbody>";
       }
       echo "</table></div>";
       Html::closeForm();
@@ -799,6 +822,19 @@ class SavedSearch extends CommonDBTM {
                });
             });\n
 
+            $('.slidepanel .toggle').on('click', function() {
+               var _this = $(this);
+               var _elt = _this.parents('thead').next('tbody');
+               _elt.toggle();
+               if (_elt.is(':visible')) {
+                  _this.removeClass('fa-chevron-circle-down')
+                     .addClass('fa-chevron-circle-up');
+               } else {
+                  _this.removeClass('fa-chevron-circle-up')
+                     .addClass('fa-chevron-circle-down');
+               }
+            });
+
          });";
 
          echo Html::scriptBlock($js);
@@ -1005,8 +1041,11 @@ class SavedSearch extends CommonDBTM {
       global $DB;
 
       $types= [];
-      foreach ($DB->request("SELECT DISTINCT(`itemtype`)
-                             FROM `" . static::getTable() . "`") as $data) {
+      $iterator = $DB->request([
+         'SELECT DISTINCT' => 'itemtype',
+         'FROM'            => static::getTable()
+      ]);
+      while ($data = $iterator->next()) {
          $types[] = $data['itemtype'];
       }
       return $types;
