@@ -1170,6 +1170,7 @@ class Toolbox {
 
    /**
     * Resize a picture to the new size
+    * Always produce a JPG file!
     *
     * @since version 0.85
     *
@@ -2491,7 +2492,16 @@ class Toolbox {
       $string = str_replace(' ', '-', self::strtolower($string, 'UTF-8'));
       $string = self::removeHtmlSpecialChars($string);
       $string = preg_replace('~[^0-9a-z]+~i', '-', $string);
-      return trim($string, '-');
+      $string = trim($string, '-');
+      if ($string == '') {
+         //prevent empty slugs; see https://github.com/glpi-project/glpi/issues/2946
+         //harcoded prefix string because html @id must begin with a letter
+         $string = 'nok_' . Toolbox::getRandomString(10);
+      } else if (ctype_digit(substr($string, 0, 1))) {
+         //starts with a number; not ok to be used as an html id attribute
+         $string = 'slug_' . $string;
+      }
+      return $string;
    }
 
    /**
@@ -2542,7 +2552,7 @@ class Toolbox {
                                  Html::entity_decode_deep($content_text), $matches);
                   foreach ($matches[0] as $match_img) {
                      //retrieve dimensions
-                     $width = $height = 50;
+                     $width = $height = null;
                      preg_match_all('/(width|height)=\\\"([^"]*)\\\"/i', $match_img, $attributes);
                      if (isset($attributes[1][0])) {
                         ${$attributes[1][0]} = $attributes[2][0];
@@ -2551,6 +2561,13 @@ class Toolbox {
                         ${$attributes[1][1]} = $attributes[2][1];
                      }
 
+                     if ($width == null || $height == null) {
+                        $path = GLPI_DOC_DIR."/".$image['filepath'];
+                        $img_infos  = getimagesize($path);
+                        $width = $img_infos[0];
+                        $height = $img_infos[1];
+                     }
+
                      // replace image
                      $new_image =  Html::convertTagFromRichTextToImageTag($image['tag'],
                                                                           $width, $height);
